@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 sub ProcessAudible_meta($$$);
 sub ProcessAudible_cvrx($$$);
@@ -40,7 +40,11 @@ sub ProcessAudible_cvrx($$$);
 
     # information extracted from other chunks
     _chapter_count => { Name => 'ChapterCount' },       # from chunk 6
-    _cover_art => { Name => 'CoverArt', Binary => 1 },  # from chunk 11
+    _cover_art => { # from chunk 11
+        Name => 'CoverArt',
+        Groups => { 2 => 'Preview' },
+        Binary => 1,
+    },
 );
 
 # 'tags' atoms observed in Audible .m4b audio books (ref PH)
@@ -86,7 +90,11 @@ sub ProcessAudible_cvrx($$$);
     NOTES => 'Audible cover art information in M4B audio books.',
     VARS => { NO_ID => 1 },
     CoverArtType => 'CoverArtType',
-    CoverArt     => { Name => 'CoverArt', Binary => 1 },
+    CoverArt     => {
+        Name => 'CoverArt',
+        Groups => { 2 => 'Preview' },
+        Binary => 1,
+    },
 );
 
 # 'tseg' information observed in Audible .m4b audio books (ref PH)
@@ -121,13 +129,13 @@ sub ProcessAudible_meta($$$)
     for ($index=0; $index<$num; ++$index) {
         last if $pos + 3 > $dirLen;
         my $unk = Get8u($dataPt, $pos);             # ? (0x80 or 0x00)
-        last unless $unk eq 0x80 or $unk eq 0x00;
+        last unless $unk == 0x80 or $unk == 0x00;
         my $len = Get16u($dataPt, $pos + 1);        # tag length
         $pos += 3;
         last if $pos + $len + 6 > $dirLen or not $len;
         my $tag = substr($$dataPt, $pos, $len);     # tag ID
         my $ver = Get16u($dataPt, $pos + $len);     # version?
-        last unless $ver eq 0x0001;
+        last unless $ver == 0x0001;
         my $size = Get32u($dataPt, $pos + $len + 2);# data size
         $pos += $len + 6;
         last if $pos + $size > $dirLen;
@@ -283,7 +291,7 @@ information from Audible audio books.
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
